@@ -8,9 +8,9 @@ use base qw( Exporter );
 BEGIN {
 
 # ABSTRACT: Implementation of getppid() for windows
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
-  if($^O =~ /^(cygwin|MSWin32)$/)
+  if($^O =~ /^(cygwin|MSWin32|msys)$/)
   {
     require XSLoader;
     XSLoader::load('Win32::Getppid', $Win32::Getppid::VERSION);
@@ -26,7 +26,7 @@ if($^O eq 'MSWin32')
   @EXPORT = qw( getppid );
   @EXPORT_OK = qw( getppid );
 }
-elsif($^O eq 'cygwin')
+elsif($^O =~ /^(cygwin|msys)$/)
 {
   @EXPORT_OK = qw( getppid );
 }
@@ -62,7 +62,7 @@ Win32::Getppid - Implementation of getppid() for windows
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
